# Ouster Lidar Plugin for NVIDIA DRIVEWORKS

## Overview
Contained here is the Ouster Lidar Plugin for NVIDIA DRIVEWORKS. The plugin is 
an implementation of NVIDIA's interface for Custom Lidars, described here: 
- https://docs.nvidia.com/drive/driveworks-3.5/sensorplugins_lidarsensor.html

The plugin itself consists of a single shared libray file. Also provided are 
examples to help you get started which also demonstrate the parameters required
by the plugin. Depending on your platform, an x86 Ubuntu 18.04 PC or DRIVE 
system, the plugin shared library can be found in: 

x86 Ubuntu 18.04 PC: 
- `./dist/x86/libouster_lidar_plugin_x86.so`

DRIVE arm platform:
- `./dist/arm/libouster_lidar_plugin_arm.so`

## Prerequisites

### Testing DRIVEWORKS installation
Ensure you have DRIVEWORKS installed and have tested by running
`/usr/local/driveworks/bin/sample_lidar_replay`

### Script directories

With an Ouster Lidar sensor connected to you system, you can get started
quickly with the provided example scripts which can be found in one of the 
following directories, depending on your platform. From here, change to the 
appropriate directory:
- `./dist/x86/bin`
    - For x86 Intel based chip architecture with Ubuntu 18.04
- `./dist/arm/bin`
    - For the NVIDIA DRIVE platform

### Increase the system's UDP buffer maximums

You may need to increase the buffer limits of the UDP buffer on the system.
A convenient script for this can be run using the following command: 
- `./max_perf.sh`

## Using the plugin

First, connect to and configure your Ouster Lidar Sensor as described in the 
Ouster Software User Manual found here: 
  - https://ouster.com/downloads/

### Live stream Ouster sensor

To live stream data from the sensor use the following command:
- `./run.sh <SESSION-ID> <DEVICE-ADDR> <HOST-ADDR> `
    - `SESSION-ID` is a unique identifier for the session which is used
	name the recording and config files, that reside in `dist/(x86|arm)/data`
    - `DEVICE-ADDR` is the IP address or hostname of the sensor
    - `HOST-ADDR` is the IP address or hostname of network adapter on this 
	system to which the sensor is connected. 

### Record sessions

To record sessions, the NVIDIA recorder tool must be used. 

1. Create a RIG file that references the plugin's shared library file for
the platform. 
    - An example rig file with the necessary parameters  for the plugin is 
    provided in the `../data` directory. 
    - NVIDIA's documentation of the RIG file can be found here: 
    https://docs.nvidia.com/drive/driveworks-3.5/rigconfiguration_usecase0.html
2. With the RIG file properly configured, recordings are executed with the 
recorder tool as follows: 
- `cd /usr/local/driveworks/tools/capture`
- `./recorder <path to RIG json file>` 
3. Once prompted, press "s" to start recording and press 'q' to stop recording.

Alternatively, to accelerate getting started with recording, an example script 
is provided that takes the same parameters as the live stream script above,
automatically creates a sample RIG file from a template, and then calls the
NVIDIA recorder tool. 
- `./record.sh <SESSION-ID> <DEVICE-ADDR> <HOST-ADDR> `
    - `SESSION-ID` is a unique identifier for the session which is used to name
    the recording and config files, that reside in `dist/(x86|arm)/data` 
    - `DEVICE-ADDR` is the IP address or hostname of the sensor
    - `HOST-ADDR` is the IP address or hostname of network adapter on this 
	system to which the sensor is connected. 

### Playback recorded sessions

To playback recorded sensor data, use the following command, with the 
recording's.bin, .bin.seek, and .cfg, files in the `../data` directory:
- `./run_recording.sh <SESSION-ID> ` 

## Plugin Parameters

The above scripts are provided as examples of how to set up the parameters for
NVIDIA DRIVEWORKS applications to properly use the Ouster plugin. 

The parameters required for operation of the plugin are detailed below:

- `device`: Must be `CUSTOM_EX`
- `ip`: The sensor's hostname or IP address 
- `dip`: The computer or DRIVE system's hostname or IP address
- `lidar_port`:  The UDP port the sensor's LIDAR messages are sent to, optional.
- `imu_port`: The UDP port the sensor's IMU messages are sent to (these are
discarded by the plugin), optional.
- `data_dir` : The directory where the plugin will store (in live mode) or
look for (in recording mode) the config file associated with the session
- `session_id`: This will be used as the name for the config file and recording
files, i.e. if `session_id = TEST_RUN`, then the config file will be 
`TEST_RUN.cfg` and the recording data files will be `TEST_RUN.bin` and 
`TEST_RUN.bin.seek` 
- `decoder-path`: The full path to the plugin shared library
- `file`: The full path to the `.bin` file containing the recording
    - This is only required if playing back from a recording

These parameters are provided to the NVIDIA DRIVEWORKS sample apps in the
`--params` command-line parameter, as shown in the example scripts, and in the
JSON element `"parameter"` in the example RIG file.

With `log_level` set to `WARN`, sufficient output to the console should happen
to indicate if parameters are missing or incorrect.
