#!/bin/bash

# this script demonstrates how to make a recording using the nvidia driveworks 
# recording tool. it uses a template rig file and replaces the template elements
# with the parameter values. the first parameter is the name of the session, and will 
# be used to name the sensor config file that will be stored for the session in the ../data
# directory. the second parameter is the ip or hostname of the sensor, and the third is the 
# ip or hostname of the computer

if [ -z "$3" ]
  then
    echo "Usage: ./record.sh SESSION_NAME SENSOR_ADDR HOST_ADDR"
    echo "  Where: "
    echo "    SESSION_NAME is used to name the recording data 
                and sensor config file that will be stored in ../data, "
    echo "    SENSOR_ADDR is the sensor's ip or hostname, and "
    echo "    HOST_ADDR is the ip or hostname of this computer "
    exit 1
fi

# store the current script directory in a variable
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
DATA_DIR="$( cd "${SCRIPT_DIR}/../data" &> /dev/null && pwd )"
PLUGIN_DIR="$( cd "${SCRIPT_DIR}/../lib" &> /dev/null && pwd )"

ARCH=$( dpkg --print-architecture )

if [ "${ARCH}" = "amd64" ]; then
    PLUGIN_FILE="libouster_lidar_plugin_x86.so"
else
    PLUGIN_FILE="libouster_lidar_plugin_arm.so"
fi

PLUGIN_PATH="${PLUGIN_DIR}/${PLUGIN_FILE}"

# create a session_id to use for recording and config filenames
# SESSION_ID="$(uuidgen)"
SESSION_ID=$1

# This must be CUSTOM_EX, placeholder for now
SENSOR_TYPE="CUSTOM_EX"

# Set your host and sensor ip/hostname and ports here
SENSOR_ADDR=$2
SENSOR_LIDAR_PORT=7502
SENSOR_IMU_PORT=7503
HOST_ADDR=$3
LOG_LEVEL="WARN"

# Replace the parameters in the template file
cat ${SCRIPT_DIR}/ouster_lidar_rig_template.json \
    | sed 's|<SESSION_ID>|'"${SESSION_ID}"'|g' \
    | sed 's|<SENSOR_TYPE>|'"${SENSOR_TYPE}"'|g' \
    | sed 's|<LOG_LEVEL>|'"${LOG_LEVEL}"'|g' \
    | sed 's|<SENSOR_ADDR>|'"${SENSOR_ADDR}"'|g' \
    | sed 's|<HOST_ADDR>|'"${HOST_ADDR}"'|g' \
    | sed 's|<PLUGIN_PATH>|'"${PLUGIN_PATH}"'|g' \
    | sed 's|<DATA_DIR>|'"${DATA_DIR}"'|g' \
    > "${DATA_DIR}/${SESSION_ID}_ouster_lidar_rig.json"

DW_CMD=/usr/local/driveworks/tools/capture/recorder

${DW_CMD} "${DATA_DIR}/${SESSION_ID}_ouster_lidar_rig.json"

# recorder puts files in same directory as this script, so move them to data directory
mv ${SCRIPT_DIR}/${SESSION_ID}.* ${DATA_DIR}