#!/bin/bash

# this script demonstrates how to play data from a live sensor using the nvidia driveworks 
# sample_lidar_replay application. the first parameter is the name of the session, and will 
# be used to name the sensor config file that will be stored for the session in the ../data
# directory. the second parameter is the ip or hostname of the sensor, and the third is the 
# ip or hostname of the computer

if [ -z "$3" ]
  then
    echo "Usage: ./run.sh SESSION_NAME SENSOR_ADDR HOST_ADDR"
    echo "  Where: "
    echo "    SESSION_NAME is used to name the sensor config file "
    echo "      that will be stored in ../data, "
    echo "    SENSOR_ADDR is the sensor's ip or hostname, and "
    echo "    HOST_ADDR is the ip or hostname of this computer "
    exit 1
fi

# store the current script directory in a variable
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
DATA_DIR="$( cd "${SCRIPT_DIR}/../data" &> /dev/null && pwd )"
PLUGIN_DIR="$( cd "${SCRIPT_DIR}/../lib" &> /dev/null && pwd )"

ARCH=$( dpkg --print-architecture )

if [ "${ARCH}" = "amd64" ]; then
    PLUGIN_FILE="libouster_lidar_plugin_x86.so"
else
    PLUGIN_FILE="libouster_lidar_plugin_arm.so"
fi

PLUGIN_PATH="${PLUGIN_DIR}/${PLUGIN_FILE}"

# create a session_id to use for recording and config filenames
SESSION_ID=$1

# This must be CUSTOM_EX, placeholder for now
SENSOR_TYPE="CUSTOM_EX"

# Set your host and sensor ip/hostname and ports here
SENSOR_ADDR=$2
SENSOR_LIDAR_PORT=7502
SENSOR_IMU_PORT=7503
HOST_ADDR=$3
LOG_LEVEL="WARN"

DW_CMD=/usr/local/driveworks/bin/sample_lidar_replay

${DW_CMD} --protocol=lidar.custom --params=device=${SENSOR_TYPE},log_level="${LOG_LEVEL}",ip=${SENSOR_ADDR},dip=${HOST_ADDR},lidar_port=${SENSOR_LIDAR_PORT},imu_port=${SENSOR_IMU_PORT},data_dir=${DATA_DIR},session_id="${SESSION_ID}",decoder-path="${PLUGIN_PATH}"